@@ -183,7 +183,6 @@ def main(args):
         "foreground": True, 
         "max_readahead": 65536, 
         "ro": True, 
-        "nothreads": True, 
     }
     if fuse_options := args.fuse_options:
         for option in fuse_options:
@@ -263,8 +262,9 @@ def main(args):
 
     if not exists(mount_point):
         import atexit
+        from os import makedirs, removedirs
+        makedirs(mount_point)
         def remove_mount_point():
-            from os import removedirs
             try:
                 removedirs(mount_point)
             except:
